@@ -100,9 +100,9 @@ protected:
 #endif //Q_WS_MAEMO_5
 
 protected:
-  QPoint lastPos;
   int timerId;
   bool timerStarted;
+  QRect viewPort;
 
 #ifdef Q_WS_MAEMO_5
   QDBusConnection dBusConnection;
@@ -270,25 +270,40 @@ void JGEQtRenderer::initializeGL()
   glEnable(GL_SCISSOR_TEST);				// Enable Clipping
 }
 
-GLvoid ReSizeGLScene(GLsizei width, GLsizei height)	// Resize The GL Window
+void JGEQtRenderer::resizeGL(int width, int height)
 {
-  JRenderer::GetInstance()->SetActualWidth(width);
-  JRenderer::GetInstance()->SetActualHeight(height);
-
-  if ((GLfloat)width / (GLfloat)height < ACTUAL_RATIO)
+  if ((GLfloat)width / (GLfloat)height <= ACTUAL_RATIO)
   {
-    glViewport(0, -((width/ACTUAL_RATIO)-height)/2, width, width / ACTUAL_RATIO);			// Reset The Current Viewport
+    viewPort.setLeft(0);
+    viewPort.setTop(-((width/ACTUAL_RATIO)-height)/2);
+    viewPort.setRight(width);
+    viewPort.setBottom(-((width/ACTUAL_RATIO)-height)/2 + width / ACTUAL_RATIO);
   }
   else
   {
-    glViewport(-(height*ACTUAL_RATIO-width)/2, 0, height * ACTUAL_RATIO, height);
+    viewPort.setLeft(-(height*ACTUAL_RATIO-width)/2);
+    viewPort.setTop(0);
+    viewPort.setRight(-(height*ACTUAL_RATIO-width)/2 + height * ACTUAL_RATIO);
+    viewPort.setBottom(height);
   }
-  glScissor(0, 0, width, height);
-}
 
-void JGEQtRenderer::resizeGL(int width, int height)
-{
-  ReSizeGLScene(width, height);
+  glViewport(viewPort.left(), viewPort.top(), viewPort.right()-viewPort.left(), viewPort.bottom()-viewPort.top());
+
+  JRenderer::GetInstance()->SetActualWidth(viewPort.right()-viewPort.left());
+  JRenderer::GetInstance()->SetActualHeight(viewPort.bottom()-viewPort.top());
+  glScissor(0, 0, width, height);
+
+#if (!defined GL_ES_VERSION_2_0) && (!defined GL_VERSION_2_0)
+  glMatrixMode (GL_PROJECTION);										// Select The Projection Matrix
+  glLoadIdentity ();													// Reset The Projection Matrix
+
+  gluOrtho2D(0.0f, (float) width-1.0f, 0.0f, (float) height-1.0f);
+
+  glMatrixMode (GL_MODELVIEW);										// Select The Modelview Matrix
+  glLoadIdentity ();													// Reset The Modelview Matrix
+
+  glDisable (GL_DEPTH_TEST);
+#endif
 }
 
 void JGEQtRenderer::paintGL()
@@ -319,25 +334,30 @@ void JGEQtRenderer::mousePressEvent(QMouseEvent *event)
 {
   if(event->button() == Qt::LeftButton)
   {
-    lastPos = event->pos();
+    QPoint lastPos = event->pos();
     // this is intended to convert window coordinate into game coordinate.
     // this is correct only if the game and window have the same aspect ratio, otherwise, it's just wrong
     int actualWidth = (int) JRenderer::GetInstance()->GetActualWidth();
     int actualHeight = (int) JRenderer::GetInstance()->GetActualHeight();
-    g_engine->LeftClicked((lastPos.x()*SCREEN_WIDTH)/actualWidth, (lastPos.y()*SCREEN_HEIGHT)/actualHeight);
-    event->accept();
-  }
-  else
-  {
-    QGLWidget::mousePressEvent(event);
-  }
-}
 
-void JGEQtRenderer::mouseReleaseEvent(QMouseEvent *event)
-{
-  if(event->button() == Qt::LeftButton)
-  {
-    QGLWidget::mouseReleaseEvent(event);
+    if (lastPos.y() >= viewPort.top() &&
+      lastPos.y() <= viewPort.bottom() &&
+      lastPos.x() <= viewPort.right() &&
+      lastPos.x() >= viewPort.left()) {
+      g_engine->LeftClicked(
+                  ((lastPos.x()-viewPort.left())*SCREEN_WIDTH)/actualWidth,
+                  ((lastPos.y()-viewPort.top())*SCREEN_HEIGHT)/actualHeight);
+#ifndef Q_WS_MAEMO_5
+      g_engine->HoldKey_NoRepeat(JGE_BTN_OK);
+#endif
+    } else if(lastPos.y()<viewPort.top()) {
+      g_engine->HoldKey_NoRepeat(JGE_BTN_MENU);
+    } else if(lastPos.y()>viewPort.bottom()) {
+      g_engine->HoldKey_NoRepeat(JGE_BTN_NEXT);
+    }
+
+//    g_engine->LeftClicked((lastPos.x()*SCREEN_WIDTH)/actualWidth, (lastPos.y()*SCREEN_HEIGHT)/actualHeight);
+    event->accept();
   }
   else if(event->button() == Qt::RightButton)
   { /* next phase please */
@@ -350,32 +370,6 @@ void JGEQtRenderer::mouseReleaseEvent(QMouseEvent *event)
     event->accept();
   }
   else
-  {
-    QGLWidget::mouseReleaseEvent(event);
-  }
-}
-
-
-void JGEQtRenderer::mouseMoveEvent(QMouseEvent *event)
-{
-  // this is intended to convert window coordinate into game coordinate.
-  // this is correct only if the game and window have the same aspect ratio, otherwise, it's just wrong
-  int actualWidth = (int) JRenderer::GetInstance()->GetActualWidth();
-  int actualHeight = (int) JRenderer::GetInstance()->GetActualHeight();
-
-  g_engine->LeftClicked((event->pos().x()*SCREEN_WIDTH)/actualWidth, (event->pos().y()*SCREEN_HEIGHT)/actualHeight);
-  event->accept();
-}
-
-/*
-void JGEQtRenderer::mousePressEvent(QMouseEvent *event)
-{
-  if(event->button() == Qt::LeftButton)
-  {
-    lastPos = event->pos();
-    event->accept();
-  }
-  else
   {
     QGLWidget::mousePressEvent(event);
   }
@@ -385,36 +379,30 @@ void JGEQtRenderer::mouseReleaseEvent(QMouseEvent *event)
 {
   if(event->button() == Qt::LeftButton)
   {
-    QPoint currentPos = event->pos();
-    int dx = currentPos.x() - lastPos.x();
-    int dy = currentPos.y() - lastPos.y();
+    QPoint lastPos = event->pos();
 
-    if(abs(dx) > abs(dy) && dx > 5)
-    {
-      g_engine->HoldKey_NoRepeat(JGE_BTN_RIGHT);
-    }
-    else if(abs(dx) > abs(dy) && dx < -5)
-    {
-      g_engine->HoldKey_NoRepeat(JGE_BTN_LEFT);
-    }
-    else if(abs(dx) < abs(dy) && dy < -5)
-    {
-      g_engine->HoldKey_NoRepeat(JGE_BTN_UP);
-    }
-    else if(abs(dx) < abs(dy) && dy > 5)
-    {
-      g_engine->HoldKey_NoRepeat(JGE_BTN_DOWN);
+    if (lastPos.y() >= viewPort.top() &&
+      lastPos.y() <= viewPort.bottom() &&
+      lastPos.x() <= viewPort.right() &&
+      lastPos.x() >= viewPort.left()) {
+#ifndef Q_WS_MAEMO_5
+      g_engine->ReleaseKey(JGE_BTN_OK);
+#endif
+    } else if(lastPos.y() < viewPort.top()) {
+      g_engine->ReleaseKey(JGE_BTN_MENU);
+    } else if(lastPos.y() > viewPort.bottom()) {
+      g_engine->ReleaseKey(JGE_BTN_NEXT);
     }
     event->accept();
   }
   else if(event->button() == Qt::RightButton)
-  {
-    g_engine->HoldKey_NoRepeat(JGE_BTN_PREV);
+  { /* next phase please */
+    g_engine->ReleaseKey(JGE_BTN_PREV);
     event->accept();
   }
   else if(event->button() == Qt::MidButton)
-  {
-    g_engine->HoldKey_NoRepeat(JGE_BTN_SEC);
+  { /* interrupt please */
+    g_engine->ReleaseKey(JGE_BTN_SEC);
     event->accept();
   }
   else
@@ -422,16 +410,37 @@ void JGEQtRenderer::mouseReleaseEvent(QMouseEvent *event)
     QGLWidget::mouseReleaseEvent(event);
   }
 }
-*/
+
+void JGEQtRenderer::mouseMoveEvent(QMouseEvent *event)
+{
+  int actualWidth = (int) JRenderer::GetInstance()->GetActualWidth();
+  int actualHeight = (int) JRenderer::GetInstance()->GetActualHeight();
+
+  QPoint lastPos = event->pos();
+
+  if (lastPos.y() >= viewPort.top() &&
+    lastPos.y() <= viewPort.bottom() &&
+    lastPos.x() <= viewPort.right() &&
+    lastPos.x() >= viewPort.left()) {
+    g_engine->LeftClicked(
+                ((lastPos.x()-viewPort.left())*SCREEN_WIDTH)/actualWidth,
+                ((lastPos.y()-viewPort.top())*SCREEN_HEIGHT)/actualHeight);
+    event->accept();
+  } else {
+    QGLWidget::mouseMoveEvent(event);
+  }
+}
 
 void JGEQtRenderer::mouseDoubleClickEvent(QMouseEvent *event)
 {
+#ifdef Q_WS_MAEMO_5
   if(event->button() == Qt::LeftButton)
   {
     g_engine->HoldKey_NoRepeat(JGE_BTN_OK);
     event->accept();
   }
   else
+#endif
   {
     QGLWidget::mouseDoubleClickEvent(event);
   }
@@ -462,7 +471,6 @@ void JGEQtRenderer::wheelEvent(QWheelEvent *event)
   event->accept();
 }
 
-
 void JGEQtRenderer::keyPressEvent(QKeyEvent *event)
 {
   switch(event->key())
@@ -488,6 +496,29 @@ void JGEQtRenderer::keyPressEvent(QKeyEvent *event)
   return;
 }
 
+void JGEQtRenderer::keyReleaseEvent(QKeyEvent *event)
+{
+    switch(event->key())
+    {
+  #ifdef Q_WS_MAEMO_5
+    case Qt::Key_F7:
+      /* interrupt please */
+      g_engine->ReleaseKey(JGE_BTN_SEC);
+      break;
+    case Qt::Key_F8:
+      /* next phase please */
+      g_engine->ReleaseKey(JGE_BTN_PREV);
+      break;
+  #endif // Q_WS_MAEMO_5
+    default:
+      g_engine->ReleaseKey((LocalKeySym)event->key());
+    }
+
+    event->accept();
+    QWidget::keyReleaseEvent(event);
+    return;
+}
+
 void JGEQtRenderer::showEvent ( QShowEvent * event )
 {
   if(!timerStarted)
@@ -512,20 +543,13 @@ void JGEQtRenderer::hideEvent ( QHideEvent * event )
   }
 }
 
-void JGEQtRenderer::keyReleaseEvent(QKeyEvent *event)
-{
-  g_engine->ReleaseKey((LocalKeySym)event->key());
-  event->accept();
-  QWidget::keyReleaseEvent(event);
-  return;
-}
-
-
 int main(int argc, char* argv[])
 {
   QApplication a( argc, argv );
   QDir::setCurrent(QCoreApplication::applicationDirPath () );
 
+  qDebug() << "Current path : " << QCoreApplication::applicationDirPath ();
+
   g_launcher = new JGameLauncher();
 
   u32 flags = g_launcher->GetInitFlags();
@@ -537,6 +561,22 @@ int main(int argc, char* argv[])
 
   g_glwidget = new JGEQtRenderer(NULL);
   g_glwidget->resize(ACTUAL_SCREEN_WIDTH, ACTUAL_SCREEN_HEIGHT);
+
+  a.setApplicationName(g_launcher->GetName());
+
+  QGLFormat::OpenGLVersionFlags glflags = g_glwidget->format().openGLVersionFlags();
+
+#ifdef Q_WS_MAEMO_5
+  if((glflags & QGLFormat::OpenGL_ES_Version_2_0) == 0)
+#else
+  if((glflags & QGLFormat::OpenGL_Version_2_0) == 0)
+#endif
+  {
+    qCritical("OpenGL flags 0x%x unsupported", (unsigned int)glflags);
+    return -1;
+  }
+
+
 #ifdef Q_WS_MAEMO_5
   // We start in fullscreen on mobile
   g_glwidget->showFullScreen();
@@ -547,7 +587,7 @@ int main(int argc, char* argv[])
 
   if (!InitGame())
   {
-      qDebug("Could not init the game\n");
+      qCritical("Could not init the game\n");
       return 1;
   }
 
