@@ -9,7 +9,7 @@
 //-------------------------------------------------------------------------------------
 #define GL_GLEXT_PROTOTYPES
 
-#if (!defined IOS) && (!defined QT_CONFIG)
+#if (!defined IOS)
 #ifdef WIN32
   #pragma warning(disable : 4786)
   #pragma comment( lib, "giflib.lib" )
@@ -353,9 +353,7 @@ JTexture::~JTexture()
 
     if (mBuffer)
     {
-#ifndef QT_CONFIG
         delete [] mBuffer;
-#endif
         mBuffer = NULL;
     }
 }
@@ -1479,7 +1477,7 @@ static int getNextPower2(int width)
 }
 
 
-#if (!defined IOS) && (!defined QT_CONFIG)
+#if (!defined IOS)
 static void jpg_null(j_decompress_ptr cinfo __attribute__((unused)))
 {
 }
@@ -2118,18 +2116,22 @@ JTexture* JRenderer::LoadTexture(const char* filename, int mode, int TextureForm
     if (tex)
     {
       tmpImage = tmpImage.convertToFormat(QImage::Format_ARGB32_Premultiplied);
-      tex->mImage = tmpImage.rgbSwapped();
+      tmpImage = tmpImage.rgbSwapped();
 
       if (mImageFilter != NULL)
-          mImageFilter->ProcessImage((PIXEL_TYPE*)tex->mImage.bits(), tex->mImage.width(), tex->mImage.height());
+          mImageFilter->ProcessImage((PIXEL_TYPE*)tmpImage.bits(), tmpImage.width(), tmpImage.height());
 
       tex->mFilter = TEX_FILTER_LINEAR;
-      tex->mWidth = tex->mImage.width();
-      tex->mHeight = tex->mImage.height();
-      tex->mTexWidth = tex->mImage.width();
-      tex->mTexHeight = tex->mImage.height();
+      tex->mWidth = tmpImage.width();
+      tex->mHeight = tmpImage.height();
+      tex->mTexWidth = getNextPower2(tmpImage.width());
+      tex->mTexHeight = getNextPower2(tmpImage.height());;
+      tex->mBuffer = new BYTE[tex->mTexWidth*tex->mTexHeight*4];
 
-      tex->mBuffer = tex->mImage.bits();
+      for(int i=0; i < tex->mHeight; i++)
+      {
+        memcpy(tex->mBuffer+(i*4*tex->mTexWidth), tmpImage.constScanLine(i), tmpImage.bytesPerLine());
+      }
     }
   } while(false);
 
@@ -2187,9 +2189,7 @@ void JRenderer::TransferTextureToGLContext(JTexture& inTexture)
                 glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, inTexture.mTexWidth, inTexture.mTexHeight, 0, GL_RGBA, GL_UNSIGNED_BYTE, inTexture.mBuffer);
             }
         }
-#ifndef QT_CONFIG
         delete [] inTexture.mBuffer;
-#endif
         inTexture.mBuffer = NULL;
 
         checkGlError();
@@ -2198,41 +2198,47 @@ void JRenderer::TransferTextureToGLContext(JTexture& inTexture)
 
 JTexture* JRenderer::CreateTexture(int width, int height, int mode __attribute__((unused)))
 {
-  checkGlError();
-  int size = width * height * sizeof(PIXEL_TYPE);			// RGBA
-
-	BYTE* buffer = new BYTE[size];
-
-	JTexture *tex = new JTexture();
-
-	if (buffer && tex)
-	{
-		tex->mFilter = TEX_FILTER_LINEAR;
-		tex->mWidth = width;
-		tex->mHeight = height;
-		tex->mTexWidth = width;
-		tex->mTexHeight = height;
-
-		GLuint texid;
-		glGenTextures(1, &texid);
-		tex->mTexId = texid;
-
-		memset(buffer, 0, size);
-
-		mCurrentTex = texid;
-		glBindTexture(GL_TEXTURE_2D, mCurrentTex);
-
-		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
-		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
-		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, width, height, 0, GL_RGBA, GL_UNSIGNED_BYTE, buffer);
-
-		delete[] buffer;
-
     checkGlError();
+    JTexture *tex = new JTexture();
+
+    if (tex)
+    {
+        int size = width * height * sizeof(PIXEL_TYPE);			// RGBA
+        BYTE* buffer = new BYTE[size];
+        if (buffer)
+        {
+            tex->mFilter = TEX_FILTER_LINEAR;
+            tex->mWidth = width;
+            tex->mHeight = height;
+            tex->mTexWidth = width;
+            tex->mTexHeight = height;
+
+            GLuint texid;
+            glGenTextures(1, &texid);
+            tex->mTexId = texid;
+
+            memset(buffer, 0, size);
+
+            mCurrentTex = texid;
+            glBindTexture(GL_TEXTURE_2D, mCurrentTex);
+
+            glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
+            glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
+            glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, width, height, 0, GL_RGBA, GL_UNSIGNED_BYTE, buffer);
+
+            delete[] buffer;
+
+	        checkGlError();
+
+        }
+        else
+        {
+            delete tex;
+            tex = NULL;
+        }
+    }
+
     return tex;
-	}
-	else
-		return NULL;
 }
 
 
