@@ -10,9 +10,6 @@
  *		Visit My Site At nehe.gamedev.net
  */
 
-int actualWidth;
-int actualHeight;
-
 #ifdef WIN32
 #include <windows.h>		// Header File For Windows
 #else
@@ -199,8 +196,8 @@ GLvoid ReSizeGLScene(GLsizei width, GLsizei height)		// Resize And Initialize Th
   if (height==0)										// Prevent A Divide By Zero By
       height=1;										// Making Height Equal One
 
-  actualWidth = width;
-  actualHeight = height;
+  JRenderer::GetInstance()->SetActualWidth(static_cast<float>(width));
+  JRenderer::GetInstance()->SetActualHeight(static_cast<float>(height));
 
   glScissor(0, 0, width, height);
   glViewport (0, 0, width, height);	// Reset The Current Viewport
@@ -353,165 +350,174 @@ void KillGLWindow(void)								// Properly Kill The Window
 BOOL CreateGLWindow(char* title, int width, int height, int bits, bool fullscreenflag)
 {
 
-  actualWidth = width;
-  actualHeight = height;
+  JRenderer::GetInstance()->SetActualWidth(static_cast<float>(width));
+  JRenderer::GetInstance()->SetActualWidth(static_cast<float>(height));
 
 
-  GLuint		PixelFormat;			// Holds The Results After Searching For A Match
+  GLuint		pixelFormat;			// Holds The Results After Searching For A Match
   WNDCLASS	wc;						// Windows Class Structure
   DWORD		dwExStyle;				// Window Extended Style
   DWORD		dwStyle;				// Window Style
-  RECT		WindowRect;				// Grabs Rectangle Upper Left / Lower Right Values
-  WindowRect.left=(long)0;			// Set Left Value To 0
-  WindowRect.right=(long)width;		// Set Right Value To Requested Width
-  WindowRect.top=(long)0;				// Set Top Value To 0
-  WindowRect.bottom=(long)height;		// Set Bottom Value To Requested Height
+  RECT		windowRect;				// Grabs Rectangle Upper Left / Lower Right Values
+
+  windowRect.left = (long) 0;
+  windowRect.top = (long) 0;
+
+  if (fullscreenflag == false)
+  {
+    windowRect.left = (::GetSystemMetrics(SM_CXSCREEN) - width) / 2;
+    windowRect.top = (::GetSystemMetrics(SM_CYSCREEN) - height) / 2;
+  }
+
+  windowRect.right = windowRect.left + (long)width;		// Set Right Value To Requested Width
+  windowRect.bottom = windowRect.top + (long)height;		// Set Bottom Value To Requested Height
+
 
   fullscreen=fullscreenflag;			// Set The Global Fullscreen Flag
 
   hInstance			= GetModuleHandle(NULL);				// Grab An Instance For Our Window
   wc.style			= CS_HREDRAW | CS_VREDRAW | CS_OWNDC;	// Redraw On Size, And Own DC For Window.
-  wc.lpfnWndProc		= (WNDPROC) WndProc;					// WndProc Handles Messages
+  wc.lpfnWndProc	= (WNDPROC) WndProc;					// WndProc Handles Messages
   wc.cbClsExtra		= 0;									// No Extra Window Data
   wc.cbWndExtra		= 0;									// No Extra Window Data
   wc.hInstance		= hInstance;							// Set The Instance
-  wc.hIcon			= LoadIcon(NULL, IDI_WINLOGO);			// Load The Default Icon
+  wc.hIcon			  = LoadIcon(NULL, IDI_WINLOGO);			// Load The Default Icon
   wc.hCursor			= LoadCursor(NULL, IDC_ARROW);			// Load The Arrow Pointer
   wc.hbrBackground	= NULL;									// No Background Required For GL
   wc.lpszMenuName		= NULL;									// We Don't Want A Menu
   wc.lpszClassName	= "OpenGL";								// Set The Class Name
 
   if (!RegisterClass(&wc))									// Attempt To Register The Window Class
-    {
-      MessageBox(NULL,"Failed To Register The Window Class.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;											// Return FALSE
-    }
+  {
+    MessageBox(NULL,"Failed To Register The Window Class.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;											// Return FALSE
+  }
 
   if (fullscreen)												// Attempt Fullscreen Mode?
-    {
-      DEVMODE dmScreenSettings;								// Device Mode
-      memset(&dmScreenSettings,0,sizeof(dmScreenSettings));	// Makes Sure Memory's Cleared
-      dmScreenSettings.dmSize=sizeof(dmScreenSettings);		// Size Of The Devmode Structure
-      dmScreenSettings.dmPelsWidth	= width;				// Selected Screen Width
-      dmScreenSettings.dmPelsHeight	= height;				// Selected Screen Height
-      dmScreenSettings.dmBitsPerPel	= bits;					// Selected Bits Per Pixel
-      dmScreenSettings.dmFields=DM_BITSPERPEL|DM_PELSWIDTH|DM_PELSHEIGHT;
+  {
+    DEVMODE dmScreenSettings;								// Device Mode
+    memset(&dmScreenSettings,0,sizeof(dmScreenSettings));	// Makes Sure Memory's Cleared
+    dmScreenSettings.dmSize=sizeof(dmScreenSettings);		// Size Of The Devmode Structure
+    dmScreenSettings.dmPelsWidth	= width;				// Selected Screen Width
+    dmScreenSettings.dmPelsHeight	= height;				// Selected Screen Height
+    dmScreenSettings.dmBitsPerPel	= bits;					// Selected Bits Per Pixel
+    dmScreenSettings.dmFields=DM_BITSPERPEL|DM_PELSWIDTH|DM_PELSHEIGHT;
 
-      // Try To Set Selected Mode And Get Results.  NOTE: CDS_FULLSCREEN Gets Rid Of Start Bar.
-      if (ChangeDisplaySettings(&dmScreenSettings,CDS_FULLSCREEN)!=DISP_CHANGE_SUCCESSFUL)
-	{
-	  // If The Mode Fails, Offer Two Options.  Quit Or Use Windowed Mode.
-	  if (MessageBox(NULL,"The Requested Fullscreen Mode Is Not Supported By\nYour Video Card. Use Windowed Mode Instead?","NeHe GL",MB_YESNO|MB_ICONEXCLAMATION)==IDYES)
-	    {
-	      fullscreen=FALSE;		// Windowed Mode Selected.  Fullscreen = FALSE
-	    }
-	  else
-	    {
-	      // Pop Up A Message Box Letting User Know The Program Is Closing.
-	      MessageBox(NULL,"Program Will Now Close.","ERROR",MB_OK|MB_ICONSTOP);
-	      return FALSE;									// Return FALSE
-	    }
-	}
+    // Try To Set Selected Mode And Get Results.  NOTE: CDS_FULLSCREEN Gets Rid Of Start Bar.
+    if (ChangeDisplaySettings(&dmScreenSettings,CDS_FULLSCREEN)!=DISP_CHANGE_SUCCESSFUL)
+    {
+      // If The Mode Fails, Offer Two Options.  Quit Or Use Windowed Mode.
+      if (MessageBox(NULL,"The Requested Fullscreen Mode Is Not Supported By\nYour Video Card. Use Windowed Mode Instead?","NeHe GL",MB_YESNO|MB_ICONEXCLAMATION)==IDYES)
+      {
+        fullscreen=FALSE;		// Windowed Mode Selected.  Fullscreen = FALSE
+      }
+      else
+      {
+        // Pop Up A Message Box Letting User Know The Program Is Closing.
+        MessageBox(NULL,"Program Will Now Close.","ERROR",MB_OK|MB_ICONSTOP);
+        return FALSE;									// Return FALSE
+      }
     }
+  }
 
   if (fullscreen)												// Are We Still In Fullscreen Mode?
-    {
-      dwExStyle=WS_EX_APPWINDOW;								// Window Extended Style
-      dwStyle=WS_POPUP;										// Windows Style
-      ShowCursor(FALSE);										// Hide Mouse Pointer
-    }
+  {
+    dwExStyle=WS_EX_APPWINDOW;								// Window Extended Style
+    dwStyle=WS_POPUP;										// Windows Style
+    ShowCursor(FALSE);										// Hide Mouse Pointer
+  }
   else
-    {
-      dwExStyle=WS_EX_APPWINDOW | WS_EX_WINDOWEDGE;			// Window Extended Style
-      //dwStyle=WS_OVERLAPPEDWINDOW;							// Windows Style
-      dwStyle= WS_OVERLAPPED     | \
-	WS_CAPTION        | \
-	WS_MINIMIZEBOX	   |
-	WS_SIZEBOX	   |
-	WS_MAXIMIZEBOX	   |
-	//WS_MINIMIZE		|
-	WS_SYSMENU;//        |
-      //WS_THICKFRAME ;
-    }
+  {
+    dwExStyle=WS_EX_APPWINDOW | WS_EX_WINDOWEDGE;			// Window Extended Style
+    //dwStyle=WS_OVERLAPPEDWINDOW;							// Windows Style
+    dwStyle= WS_OVERLAPPED     | \
+      WS_CAPTION        | \
+      WS_MINIMIZEBOX	   |
+      WS_SIZEBOX	   |
+      WS_MAXIMIZEBOX	   |
+      //WS_MINIMIZE		|
+      WS_SYSMENU;//        |
+    //WS_THICKFRAME ;
+  }
 
-  AdjustWindowRectEx(&WindowRect, dwStyle, FALSE, dwExStyle);		// Adjust Window To True Requested Size
+  AdjustWindowRectEx(&windowRect, dwStyle, FALSE, dwExStyle);		// Adjust Window To True Requested Size
 
   // Create The Window
   if (!(hWnd=CreateWindowEx(	dwExStyle,							// Extended Style For The Window
-				"OpenGL",							// Class Name
-				title,								// Window Title
-				dwStyle |							// Defined Window Style
-				WS_CLIPSIBLINGS |					// Required Window Style
-				WS_CLIPCHILDREN,					// Required Window Style
-				0, 0,								// Window Position
-				WindowRect.right-WindowRect.left,	// Calculate Window Width
-				WindowRect.bottom-WindowRect.top,	// Calculate Window Height
-				NULL,								// No Parent Window
-				NULL,								// No Menu
-				hInstance,							// Instance
-				NULL)))								// Dont Pass Anything To WM_CREATE
-    {
-      KillGLWindow();								// Reset The Display
-      MessageBox(NULL,"Window Creation Error.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;								// Return FALSE
-    }
+    "OpenGL",							// Class Name
+    title,								// Window Title
+    dwStyle |							// Defined Window Style
+    WS_CLIPSIBLINGS |					// Required Window Style
+    WS_CLIPCHILDREN,					// Required Window Style
+    windowRect.left, windowRect.top,	// Window Position
+    windowRect.right-windowRect.left,	// Calculate Window Width
+    windowRect.bottom-windowRect.top,	// Calculate Window Height
+    NULL,								// No Parent Window
+    NULL,								// No Menu
+    hInstance,							// Instance
+    NULL)))								// Dont Pass Anything To WM_CREATE
+  {
+    KillGLWindow();								// Reset The Display
+    MessageBox(NULL,"Window Creation Error.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;								// Return FALSE
+  }
 
   static	PIXELFORMATDESCRIPTOR pfd=				// pfd Tells Windows How We Want Things To Be
-    {
-      sizeof(PIXELFORMATDESCRIPTOR),				// Size Of This Pixel Format Descriptor
-      1,											// Version Number
-      PFD_DRAW_TO_WINDOW |						// Format Must Support Window
-      PFD_SUPPORT_OPENGL |						// Format Must Support OpenGL
-      PFD_DOUBLEBUFFER,							// Must Support Double Buffering
-      PFD_TYPE_RGBA,								// Request An RGBA Format
-      bits,										// Select Our Color Depth
-      0, 0, 0, 0, 0, 0,							// Color Bits Ignored
-      0,											// No Alpha Buffer
-      0,											// Shift Bit Ignored
-      0,											// No Accumulation Buffer
-      0, 0, 0, 0,									// Accumulation Bits Ignored
-      16,											// 16Bit Z-Buffer (Depth Buffer)
-      0,											// No Stencil Buffer
-      0,											// No Auxiliary Buffer
-      PFD_MAIN_PLANE,								// Main Drawing Layer
-      0,											// Reserved
-      0, 0, 0										// Layer Masks Ignored
-    };
+  {
+    sizeof(PIXELFORMATDESCRIPTOR),				// Size Of This Pixel Format Descriptor
+    1,											// Version Number
+    PFD_DRAW_TO_WINDOW |						// Format Must Support Window
+    PFD_SUPPORT_OPENGL |						// Format Must Support OpenGL
+    PFD_DOUBLEBUFFER,							// Must Support Double Buffering
+    PFD_TYPE_RGBA,								// Request An RGBA Format
+    bits,										// Select Our Color Depth
+    0, 0, 0, 0, 0, 0,							// Color Bits Ignored
+    0,											// No Alpha Buffer
+    0,											// Shift Bit Ignored
+    0,											// No Accumulation Buffer
+    0, 0, 0, 0,									// Accumulation Bits Ignored
+    16,											// 16Bit Z-Buffer (Depth Buffer)
+    0,											// No Stencil Buffer
+    0,											// No Auxiliary Buffer
+    PFD_MAIN_PLANE,								// Main Drawing Layer
+    0,											// Reserved
+    0, 0, 0										// Layer Masks Ignored
+  };
 
   if (!(hDC=GetDC(hWnd)))							// Did We Get A Device Context?
-    {
-      KillGLWindow();								// Reset The Display
-      MessageBox(NULL,"Can't Create A GL Device Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;								// Return FALSE
-    }
+  {
+    KillGLWindow();								// Reset The Display
+    MessageBox(NULL,"Can't Create A GL Device Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;								// Return FALSE
+  }
 
-  if (!(PixelFormat=ChoosePixelFormat(hDC,&pfd)))	// Did Windows Find A Matching Pixel Format?
-    {
-      KillGLWindow();								// Reset The Display
-      MessageBox(NULL,"Can't Find A Suitable PixelFormat.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;								// Return FALSE
-    }
+  if (!(pixelFormat=ChoosePixelFormat(hDC,&pfd)))	// Did Windows Find A Matching Pixel Format?
+  {
+    KillGLWindow();								// Reset The Display
+    MessageBox(NULL,"Can't Find A Suitable PixelFormat.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;								// Return FALSE
+  }
 
-  if(!SetPixelFormat(hDC,PixelFormat,&pfd))		// Are We Able To Set The Pixel Format?
-    {
-      KillGLWindow();								// Reset The Display
-      MessageBox(NULL,"Can't Set The PixelFormat.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;								// Return FALSE
-    }
+  if(!SetPixelFormat(hDC,pixelFormat,&pfd))		// Are We Able To Set The Pixel Format?
+  {
+    KillGLWindow();								// Reset The Display
+    MessageBox(NULL,"Can't Set The PixelFormat.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;								// Return FALSE
+  }
 
   if (!(hRC=wglCreateContext(hDC)))				// Are We Able To Get A Rendering Context?
-    {
-      KillGLWindow();								// Reset The Display
-      MessageBox(NULL,"Can't Create A GL Rendering Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;								// Return FALSE
-    }
+  {
+    KillGLWindow();								// Reset The Display
+    MessageBox(NULL,"Can't Create A GL Rendering Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;								// Return FALSE
+  }
 
   if(!wglMakeCurrent(hDC,hRC))					// Try To Activate The Rendering Context
-    {
-      KillGLWindow();								// Reset The Display
-      MessageBox(NULL,"Can't Activate The GL Rendering Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;								// Return FALSE
-    }
+  {
+    KillGLWindow();								// Reset The Display
+    MessageBox(NULL,"Can't Activate The GL Rendering Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;								// Return FALSE
+  }
 
   ShowWindow(hWnd,SW_SHOW);						// Show The Window
   SetForegroundWindow(hWnd);						// Slightly Higher Priority
@@ -519,18 +525,18 @@ BOOL CreateGLWindow(char* title, int width, int height, int bits, bool fullscree
   ReSizeGLScene(width, height);					// Set Up Our Perspective GL Screen
 
   if (!InitGL())									// Initialize Our Newly Created GL Window
-    {
-      KillGLWindow();								// Reset The Display
-      MessageBox(NULL,"Initialization Failed.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;								// Return FALSE
-    }
+  {
+    KillGLWindow();								// Reset The Display
+    MessageBox(NULL,"Initialization Failed.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;								// Return FALSE
+  }
 
   if (!InitGame())								// Initialize Our Game
-    {
-      KillGLWindow();								// Reset The Display
-      MessageBox(NULL,"Game Initialization Failed.","ERROR",MB_OK|MB_ICONEXCLAMATION);
-      return FALSE;								// Return FALSE
-    }
+  {
+    KillGLWindow();								// Reset The Display
+    MessageBox(NULL,"Game Initialization Failed.","ERROR",MB_OK|MB_ICONEXCLAMATION);
+    return FALSE;								// Return FALSE
+  }
 
   return TRUE;									// Success
 }
