@@ -4,7 +4,7 @@
 #include <string>
 #include <vector>
 #include <map>
-#include "../include/DeckStats.h"
+#include "DeckStats.h"
 
 
 using namespace std;
@@ -22,6 +22,7 @@ private:
   string _desc;
   string _name;
   int _deckid;
+  string _avatarFilename;
 
   // statistical information
   
@@ -31,21 +32,29 @@ public:
   DeckMetaData();
   DeckMetaData(string filename, Player * statsPlayer);
   void load(string filename);
-  void loadStatsForPlayer( Player * statsPlayer, string opponentDeckName = "" );
+  void loadStatsForPlayer( Player * statsPlayer, string deckStatsFileName = "" );
   
   // Accessors
   string getFilename();
   string getDescription();
   string getName();
+  string getAvatarFilename();
+  int getAvatarId(int deckId);
+  string getStatsSummary();
+
   int getDeckId();
   int getGamesPlayed();
   int getVictories();
   int getVictoryPercentage();
   int getDifficulty();
+  string getDifficultyString();
 
 };
 
 class DeckMetaDataList {
+private:
+  map<string,DeckMetaData *>values; 
+
 public:
   void invalidate(string filename);
   DeckMetaData * get(string filename, Player * statsPlayer = NULL);
@@ -53,8 +62,6 @@ public:
   static DeckMetaDataList * decksMetaData;
 
   
-private:
-  map<string,DeckMetaData *>values;
 };
 
 #endif
