@@ -1,7 +1,7 @@
 #ifndef _MENU_ITEM_H
 #define _MENU_ITEM_H
 
-#include "../include/WFont.h"
+#include "WFont.h"
 #include <JGui.h>
 #include <hge/hgeparticle.h>
 #include <string>
@@ -18,8 +18,8 @@ class MenuItem: public JGuiObject
   bool mHasFocus;
   WFont *mFont;
   string mText;
-  int mX;
-  int mY;
+  float mX;
+  float mY;
   int updatedSinceLastRender;
   float lastDt;
 
@@ -31,7 +31,7 @@ class MenuItem: public JGuiObject
 
 
  public:
-  MenuItem(int id, WFont *font, string text, int x, int y, JQuad * _off, JQuad * _on, const char * particle, JQuad * particleQuad, bool hasFocus = false);
+  MenuItem(int id, WFont *font, string text, float x, float y, JQuad * _off, JQuad * _on, const char * particle, JQuad * particleQuad, bool hasFocus = false);
   ~MenuItem();
   virtual void Render();
   virtual void Update(float dt);
@@ -39,6 +39,7 @@ class MenuItem: public JGuiObject
   virtual void Entering();
   virtual bool Leaving(JButton key);
   virtual bool ButtonPressed();
+  virtual bool getTopLeft(float& top, float& left) {top = mY; left = mX; return true;};
 
   virtual ostream& toString(ostream& out) const;
 };
