@@ -32,6 +32,9 @@ const string Options::optionNames[] = {
   "transitions",
   "bgStyle",
   "interruptSeconds",
+#if defined(QT_CONFIG)
+  "keybindings_qt",
+#else
 #if defined(WIN32)
   "keybindings_win",
 #else
@@ -40,6 +43,7 @@ const string Options::optionNames[] = {
 #else
   "keybindings_psp",
 #endif
+#endif
 #endif
   "aidecks",
   "interruptMySpells",
